@@ -277,11 +277,13 @@ class RFStream(Stream):
             method with the angles given by the back_azimuth and inclination
             attributes of the traces stats objects. You can set these to your
             needs or let them be computed by :func:`~rf.rfstream.rfstats`.
-        :param deconvolve: 'time' or 'freq' for time or frequency domain
-            deconvolution by the streams
+        :param deconvolve: 'time', 'freq', 'iter', or 'multi' for time domain
+            water level, frequency domain water level, time domain iterative, or
+            frequency domain multitaper deconvolution using the stream's
             `deconvolve()`
             method. See `~.deconvolve.deconvolve()`,
-            `.deconvt()` and `.deconvf()`
+            `.deconv_time()`, `.deconv_waterlevel()`,
+            `.deconv_iterative()`, and `.deconv_multitaper()`
             for further documentation.
         :param source_components: parameter is passed to deconvolve.
             If None, source components will be chosen depending on method.
@@ -380,7 +382,7 @@ class RFStream(Stream):
         :param pp_depth: depth of interface in km
         :param pp_phase: 'P' for piercing points of P wave, 'S' for piercing
             points of S wave or multiples, if None will be
-            set to 'S' for P receiver functions or 'S' for S receiver functions
+            set to 'S' for P receiver functions or 'P' for S receiver functions
         :param model: path to model file (see `.SimpleModel`, default: iasp91)
         :return: NumPy array with coordinates of piercing points
         """
